Module: ROM::LDAP::Directory::Tokenization Private
- Included in:
- ROM::LDAP::Directory
- Defined in:
- lib/rom/ldap/directory/tokenization.rb
Overview
This module is part of a private API. You should avoid using this module if possible, as it may be removed or be changed in the future.
Parsing Formats
Class Method Summary collapse
-
.included(klass) ⇒ Object
private
Allows adapters that subclass Directory to use custom parsers.
Class Method Details
.included(klass) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Allows adapters that subclass Directory to use custom parsers. Extends the class with filter abstraction behavior.
19 20 21 22 23 24 25 26 27 28 29 30 31 32 |
# File 'lib/rom/ldap/directory/tokenization.rb', line 19 def self.included(klass) klass.class_eval do extend Dry::Core::ClassAttributes defines :attribute_class attribute_class Parsers::Attribute defines :filter_class filter_class Parsers::FilterSyntax defines :ast_class ast_class Parsers::AbstractSyntax end end |